@@ -1,10 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import os
-
-from json import encoder
-from json import dumps
-
 from sklearn_export.estimator.classifier.Classifier import Classifier
 
 
@@ -30,9 +25,6 @@ class LogisticRegression(Classifier):
         if model_data is None:
             model_data = {}
 
-        if 'type' not in model_data:
-            model_data['type'] = ''
-
         model_data['coefficients'] = self.estimator.coef_.flatten('F').tolist()
         model_data['numRows'] = self.estimator.coef_.shape[0]
         model_data['numColumns'] = self.estimator.coef_.shape[1]
@@ -40,12 +32,12 @@ class LogisticRegression(Classifier):
 
         if self.estimator.multi_class is 'multinomial':
             if len(self.estimator.classes_) > 2:
-                model_data['type'] += 'MultinomialLogisticRegression'
+                model_data['type'] = 'MultinomialLogisticRegression'
             else:
-                model_data['type'] += 'BinaryLogisticRegression'
+                model_data['type'] = 'BinaryLogisticRegression'
         elif len(self.estimator.classes_) > 2:
-            model_data['type'] += 'MulticlassLogisticRegression'
+            model_data['type'] = 'MulticlassLogisticRegression'
         else:
-            model_data['type'] += 'BinaryLogisticRegression'
+            model_data['type'] = 'BinaryLogisticRegression'
 
         return model_data
\ No newline at end of file
